@@ -1,7 +1,6 @@
 package v1beta1
 
 import (
-	conditionsv1 "github.com/openshift/custom-resource-status/conditions/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	sdkapi "kubevirt.io/controller-lifecycle-operator-sdk/pkg/sdk/api"
@@ -38,13 +37,13 @@ type HyperConvergedSpec struct {
 
 	// featureGates is a map of feature gate flags. Setting a flag to `true` will enable
 	// the feature. Setting `false` or removing the feature gate, disables the feature.
-	// +kubebuilder:default={"withHostPassthroughCPU": false, "sriovLiveMigration": false}
+	// +kubebuilder:default={"withHostPassthroughCPU": false, "sriovLiveMigration": true}
 	// +optional
 	FeatureGates HyperConvergedFeatureGates `json:"featureGates,omitempty"`
 
 	// Live migration limits and timeouts are applied so that migration processes do not
 	// overwhelm the cluster.
-	// +kubebuilder:default={"bandwidthPerMigration": "64Mi", "completionTimeoutPerGiB": 800, "parallelMigrationsPerCluster": 5, "parallelOutboundMigrationsPerNode": 2, "progressTimeout": 150}
+	// +kubebuilder:default={"completionTimeoutPerGiB": 800, "parallelMigrationsPerCluster": 5, "parallelOutboundMigrationsPerNode": 2, "progressTimeout": 150}
 	// +optional
 	LiveMigrationConfig LiveMigrationConfigurations `json:"liveMigrationConfig,omitempty"`
 
@@ -77,13 +76,18 @@ type HyperConvergedSpec struct {
 	// +optional
 	ObsoleteCPUs *HyperConvergedObsoleteCPUs `json:"obsoleteCPUs,omitempty"`
 
+	// CommonTemplatesNamespace defines namespace in which common templates will
+	// be deployed. It overrides the default openshift namespace.
+	// +optional
+	CommonTemplatesNamespace *string `json:"commonTemplatesNamespace,omitempty"`
+
 	// StorageImport contains configuration for importing containerized data
 	// +optional
 	StorageImport *StorageImportConfig `json:"storageImport,omitempty"`
 
-	// operator version
+	// WorkloadUpdateStrategy defines at the cluster level how to handle automated workload updates
 	// +optional
-	Version string `json:"version,omitempty"`
+	WorkloadUpdateStrategy *HyperConvergedWorkloadUpdateStrategy `json:"workloadUpdateStrategy,omitempty"`
 }
 
 // CertRotateConfigCA contains the tunables for TLS certificates.
@@ -159,7 +163,6 @@ type LiveMigrationConfigurations struct {
 
 	// Bandwidth limit of each migration, in MiB/s.
 	// +optional
-	// +kubebuilder:default="64Mi"
 	// +kubebuilder:validation:Pattern=^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$
 	BandwidthPerMigration *string `json:"bandwidthPerMigration,omitempty"`
 
@@ -188,11 +191,8 @@ type HyperConvergedFeatureGates struct {
 	WithHostPassthroughCPU bool `json:"withHostPassthroughCPU"`
 
 	// Allow migrating a virtual machine with SRIOV interfaces.
-	// When enabled virt-launcher pods of virtual machines with SRIOV
-	// interfaces run with CAP_SYS_RESOURCE capability.
-	// This may degrade virt-launcher security.
 	// +optional
-	// +kubebuilder:default=false
+	// +kubebuilder:default=true
 	SRIOVLiveMigration bool `json:"sriovLiveMigration"`
 }
 
@@ -273,6 +273,35 @@ type StorageImportConfig struct {
 	InsecureRegistries []string `json:"insecureRegistries,omitempty"`
 }
 
+//
+// HyperConvergedWorkloadUpdateStrategy defines options related to updating a KubeVirt install
+//
+// +k8s:openapi-gen=true
+type HyperConvergedWorkloadUpdateStrategy struct {
+	// WorkloadUpdateMethods defines the methods that can be used to disrupt workloads
+	// during automated workload updates.
+	// When multiple methods are present, the least disruptive method takes
+	// precedence over more disruptive methods. For example if both LiveMigrate and Evict
+	// methods are listed, only VMs which are not live migratable will be restarted/shutdown.
+	// An empty list defaults to no automated workload updating.
+	//
+	// +listType=atomic
+	// +optional
+	WorkloadUpdateMethods []string `json:"workloadUpdateMethods,omitempty"`
+
+	// BatchEvictionSize Represents the number of VMIs that can be forced updated per
+	// the BatchShutdownInteral interval
+	//
+	// +optional
+	BatchEvictionSize *int `json:"batchEvictionSize,omitempty"`
+
+	// BatchEvictionInterval Represents the interval to wait before issuing the next
+	// batch of shutdowns
+	//
+	// +optional
+	BatchEvictionInterval *metav1.Duration `json:"batchEvictionInterval,omitempty"`
+}
+
 // HyperConvergedStatus defines the observed state of HyperConverged
 // +k8s:openapi-gen=true
 type HyperConvergedStatus struct {
@@ -280,7 +309,7 @@ type HyperConvergedStatus struct {
 	// +patchMergeKey=type
 	// +patchStrategy=merge
 	// +optional
-	Conditions []conditionsv1.Condition `json:"conditions,omitempty"  patchStrategy:"merge" patchMergeKey:"type"`
+	Conditions []metav1.Condition `json:"conditions,omitempty"  patchStrategy:"merge" patchMergeKey:"type"`
 
 	// RelatedObjects is a list of objects created and maintained by this
 	// operator. Object references will be added to this list after they have
@@ -293,6 +322,11 @@ type HyperConvergedStatus struct {
 	// https://github.com/openshift/cluster-version-operator/blob/master/docs/dev/clusteroperator.md#version
 	// +optional
 	Versions Versions `json:"versions,omitempty"`
+
+	// ObservedGeneration reflects the HyperConverged resource generation. If the ObservedGeneration is less than the
+	// resource generation in metadata, the status is out of date
+	// +optional
+	ObservedGeneration int64 `json:"observedGeneration,omitempty"`
 }
 
 func (hcs *HyperConvergedStatus) UpdateVersion(name, version string) {
@@ -337,15 +371,31 @@ func (vs *Versions) getVersion(name string) (string, bool) {
 }
 
 const (
+	ConditionAvailable = "Available"
+
+	// ConditionProgressing indicates that the operator is actively making changes to the resources maintained by the
+	// operator
+	ConditionProgressing = "Progressing"
+
+	// ConditionDegraded indicates that the resources maintained by the operator are not functioning completely.
+	// An example of a degraded state would be if not all pods in a deployment were running.
+	// It may still be available, but it is degraded
+	ConditionDegraded = "Degraded"
+
+	// ConditionUpgradeable indicates whether the resources maintained by the operator are in a state that is safe to upgrade.
+	// When `False`, the resources maintained by the operator should not be upgraded and the
+	// message field should contain a human readable description of what the administrator should do to
+	// allow the operator to successfully update the resources maintained by the operator.
+	ConditionUpgradeable = "Upgradeable"
 
 	// ConditionReconcileComplete communicates the status of the HyperConverged resource's
 	// reconcile functionality. Basically, is the Reconcile function running to completion.
-	ConditionReconcileComplete conditionsv1.ConditionType = "ReconcileComplete"
+	ConditionReconcileComplete = "ReconcileComplete"
 
 	// ConditionTaintedConfiguration indicates that a hidden/debug configuration
 	// has been applied to the HyperConverged resource via a specialized annotation.
 	// This condition is exposed only when its value is True, and is otherwise hidden.
-	ConditionTaintedConfiguration conditionsv1.ConditionType = "TaintedConfiguration"
+	ConditionTaintedConfiguration = "TaintedConfiguration"
 )
 
 // +k8s:deepcopy-gen:interfaces=k8s.io/apimachinery/pkg/runtime.Object
@@ -360,7 +410,7 @@ type HyperConverged struct {
 	metav1.TypeMeta   `json:",inline"`
 	metav1.ObjectMeta `json:"metadata,omitempty"`
 
-	// +kubebuilder:default={"certConfig": {"ca": {"duration": "48h0m0s", "renewBefore": "24h0m0s"}, "server": {"duration": "24h0m0s", "renewBefore": "12h0m0s"}}, "featureGates": {"withHostPassthroughCPU": false, "sriovLiveMigration": false}, "liveMigrationConfig": {"bandwidthPerMigration": "64Mi", "completionTimeoutPerGiB": 800, "parallelMigrationsPerCluster": 5, "parallelOutboundMigrationsPerNode": 2, "progressTimeout": 150}}
+	// +kubebuilder:default={"certConfig": {"ca": {"duration": "48h0m0s", "renewBefore": "24h0m0s"}, "server": {"duration": "24h0m0s", "renewBefore": "12h0m0s"}}, "featureGates": {"withHostPassthroughCPU": false, "sriovLiveMigration": true}, "liveMigrationConfig": {"completionTimeoutPerGiB": 800, "parallelMigrationsPerCluster": 5, "parallelOutboundMigrationsPerNode": 2, "progressTimeout": 150}}
 	// +optional
 	Spec   HyperConvergedSpec   `json:"spec,omitempty"`
 	Status HyperConvergedStatus `json:"status,omitempty"`
