@@ -82,6 +82,7 @@ var (
 	vmImportCsv         = flag.String("vmimport-csv", "", "Virtual Machine Import Operator CSV String")
 	operatorImage       = flag.String("operator-image-name", "", "HyperConverged Cluster Operator image")
 	webhookImage        = flag.String("webhook-image-name", "", "HyperConverged Cluster Webhook image")
+	cliDownloadsImage   = flag.String("cli-downloads-image-name", "", "Downloads Server image")
 	imsConversionImage  = flag.String("ims-conversion-image-name", "", "IMS conversion image")
 	imsVMWareImage      = flag.String("ims-vmware-image-name", "", "IMS VMWare image")
 	kvVirtIOWinImage    = flag.String("kv-virtiowin-image-name", "", "KubeVirt VirtIO Win image")
@@ -360,13 +361,6 @@ func processOneCsv(c util.CsvWithComponent, i int, installStrategyBase *csvv1alp
 
 	strategySpec := csvStruct.Spec.InstallStrategy.StrategySpec
 
-	// temporary workaround for https://bugzilla.redhat.com/1907381
-	// a custom .spec.template.annotations["description"] it's causing a failure on OLM
-	// TODO: remove this once fixed on OLM side
-	for _, deployment := range strategySpec.DeploymentSpecs {
-		delete(deployment.Spec.Template.Annotations, "description")
-	}
-
 	overwriteDeploymentSpecLabels(strategySpec.DeploymentSpecs, c.Component)
 	installStrategyBase.DeploymentSpecs = append(installStrategyBase.DeploymentSpecs, strategySpec.DeploymentSpecs...)
 
@@ -497,6 +491,7 @@ func getDeploymentParams() *components.DeploymentOperatorParams {
 		Namespace:           *namespace,
 		Image:               *operatorImage,
 		WebhookImage:        *webhookImage,
+		CliDownloadsImage:   *cliDownloadsImage,
 		ImagePullPolicy:     "IfNotPresent",
 		ConversionContainer: *imsConversionImage,
 		VmwareContainer:     *imsVMWareImage,
